@@ -67,7 +67,7 @@ class RestInput(InputChannel):
         metadata: Optional[Dict[Text, Any]],
     ) -> Callable[[Any], Awaitable[None]]:
         async def stream(resp: Any) -> None:
-            q = Queue()
+            q: Queue = Queue()
             task = asyncio.ensure_future(
                 self.on_message_wrapper(
                     on_new_message, text, q, sender_id, input_channel, metadata
@@ -86,9 +86,16 @@ class RestInput(InputChannel):
     def blueprint(
         self, on_new_message: Callable[[UserMessage], Awaitable[None]]
     ) -> Blueprint:
+        """Groups the collection of endpoints used by rest channel."""
+        module_type = inspect.getmodule(self)
+        if module_type is not None:
+            module_name = module_type.__name__
+        else:
+            module_name = None
+
         custom_webhook = Blueprint(
             "custom_webhook_{}".format(type(self).__name__),
-            inspect.getmodule(self).__name__,
+            module_name,
         )
 
         # noinspection PyUnusedLocal
@@ -145,8 +152,11 @@ class QueueOutputChannel(CollectingOutputChannel):
 
     (doesn't send them anywhere, just collects them)."""
 
+    messages: Queue
+
     @classmethod
     def name(cls) -> Text:
+        """Name of QueueOutputChannel."""
         return "queue"
 
     # noinspection PyMissingConstructor
