@@ -85,6 +85,7 @@ class TwilioVoiceInput(InputChannel):
         "Polly.Astrid",
         "Polly.Filiz",
         "Polly.Gwyneth",
+        "Polly.Aditi",
     ]
 
     SUPPORTED_SPEECH_MODELS = ["default", "numbers_and_commands", "phone_call"]
@@ -116,9 +117,9 @@ class TwilioVoiceInput(InputChannel):
         initial_prompt: Optional[Text],
         reprompt_fallback_phrase: Optional[Text],
         assistant_voice: Optional[Text],
-        speech_timeout: Optional[Text],
-        speech_model: Optional[Text],
-        enhanced: Optional[Text],
+        speech_timeout: Text = "5",
+        speech_model: Text = "default",
+        enhanced: Text = "false",
     ) -> None:
         """Creates a connection to Twilio voice.
 
@@ -153,16 +154,21 @@ class TwilioVoiceInput(InputChannel):
         if self.speech_model not in self.SUPPORTED_SPEECH_MODELS:
             self._raise_invalid_speech_model_exception()
 
-        if self.enhanced.lower() not in ["true", "false"]:
+        if self.enhanced.lower() not in [
+            "true",
+            "false",
+        ]:
             self._raise_invalid_enhanced_option_exception()
 
-        if (self.enhanced.lower() == "true") and (
-            self.speech_model.lower() != "phone_call"
+        if (
+            self.enhanced.lower() == "true"
+            and self.speech_model.lower() != "phone_call"
         ):
             self._raise_invalid_enhanced_speech_model_exception()
 
-        if (self.speech_model.lower() != "numbers_and_commands") and (
-            self.speech_timeout.lower() == "auto"
+        if (
+            self.speech_model.lower() != "numbers_and_commands"
+            and self.speech_timeout.lower() == "auto"
         ):
             self._raise_invalid_speech_model_timeout_exception()
 
