@@ -50,7 +50,14 @@ from rasa.shared.core.constants import (
 from rasa.core import run, utils
 import rasa.core.train
 from rasa.core.constants import DEFAULT_SERVER_FORMAT, DEFAULT_SERVER_PORT
-from rasa.shared.core.domain import Domain
+from rasa.shared.core.domain import (
+    Domain,
+    KEY_INTENTS,
+    KEY_ENTITIES,
+    KEY_RESPONSES,
+    KEY_ACTIONS,
+    KEY_RESPONSES_TEXT,
+)
 import rasa.shared.core.events
 from rasa.shared.core.events import (
     ActionExecuted,
@@ -108,7 +115,7 @@ OTHER_INTENT = uuid.uuid4().hex
 OTHER_ACTION = uuid.uuid4().hex
 NEW_ACTION = uuid.uuid4().hex
 
-NEW_RESPONSES = {}
+NEW_RESPONSES: Dict[Text, List[Dict[Text, Any]]] = {}
 
 MAX_NUMBER_OF_TRAINING_STORIES_FOR_VISUALIZATION = 200
 
@@ -222,7 +229,8 @@ async def send_action(
             if action_name in NEW_RESPONSES:
                 warning_questions = questionary.confirm(
                     f"WARNING: You have created a new action: '{action_name}', "
-                    f"with matching response: '{[*NEW_RESPONSES[action_name]][0]}'. "
+                    f"with matching response: "
+                    f"'{NEW_RESPONSES[action_name][0][KEY_RESPONSES_TEXT]}'. "
                     f"This action will not return its message in this session, "
                     f"but the new response will be saved to your domain file "
                     f"when you exit and save this session. "
@@ -312,9 +320,8 @@ async def _ask_questions(
     is_abort: Callable[[Dict[Text, Any]], bool] = lambda x: False,
 ) -> Any:
     """Ask the user a question, if Ctrl-C is pressed provide user with menu."""
-
     should_retry = True
-    answers = {}
+    answers: Any = {}
 
     while should_retry:
         answers = questions.ask()
@@ -329,7 +336,6 @@ def _selection_choices_from_intent_prediction(
     predictions: List[Dict[Text, Any]]
 ) -> List[Dict[Text, Any]]:
     """Given a list of ML predictions create a UI choice list."""
-
     sorted_intents = sorted(
         predictions, key=lambda k: (-k["confidence"], k[INTENT_NAME_KEY])
     )
@@ -696,7 +702,7 @@ async def _request_action_from_user(
             utter_message = await _request_free_text_utterance(
                 conversation_id, endpoint, action_name
             )
-            NEW_RESPONSES[action_name] = {utter_message: ""}
+            NEW_RESPONSES[action_name] = [{KEY_RESPONSES_TEXT: utter_message}]
 
     elif action_name[:32] == OTHER_ACTION:
         # action was newly created in the session, but not this turn
@@ -917,7 +923,7 @@ def _write_domain_to_file(
 
     messages = _collect_messages(events)
     actions = _collect_actions(events)
-    responses = NEW_RESPONSES  # type: Dict[Text, List[Dict[Text, Any]]]
+    responses = NEW_RESPONSES
 
     # TODO for now there is no way to distinguish between action and form
     collected_actions = list(
@@ -929,16 +935,16 @@ def _write_domain_to_file(
         }
     )
 
-    new_domain = Domain(
-        intents=_intents_from_messages(messages),
-        entities=_entities_from_messages(messages),
-        slots=[],
-        responses=responses,
-        action_names=collected_actions,
-        forms={},
+    new_domain = Domain.from_dict(
+        {
+            KEY_INTENTS: list(_intents_from_messages(messages)),
+            KEY_ENTITIES: _entities_from_messages(messages),
+            KEY_RESPONSES: responses,
+            KEY_ACTIONS: collected_actions,
+        }
     )
 
-    old_domain.merge(new_domain).persist_clean(domain_path)
+    old_domain.merge(new_domain).persist(domain_path)
 
 
 async def _predict_till_next_listen(
@@ -952,7 +958,10 @@ async def _predict_till_next_listen(
     listen = False
     while not listen:
         result = await request_prediction(endpoint, conversation_id)
-        predictions = result.get("scores") or []
+        if result is None:
+            result = {}
+
+        predictions = result.get("scores", [])
         if not predictions:
             raise InvalidConfigException(
                 "Cannot continue as no action was predicted by the dialogue manager. "
@@ -1017,7 +1026,6 @@ async def _correct_wrong_nlu(
     conversation_id: Text,
 ) -> None:
     """A wrong NLU prediction got corrected, update core's tracker."""
-
     revert_latest_user_utterance = UserUtteranceReverted().as_dict()
     # `UserUtteranceReverted` also removes the `ACTION_LISTEN` event before, hence we
     # have to replay it.
@@ -1042,7 +1050,6 @@ async def _correct_wrong_action(
     is_new_action: bool = False,
 ) -> None:
     """A wrong action prediction got corrected, update core's tracker."""
-
     await send_action(
         endpoint, conversation_id, corrected_action, is_new_action=is_new_action
     )
@@ -1074,8 +1081,8 @@ async def _confirm_form_validation(
 ) -> None:
     """Ask a user whether an input for a form should be validated.
 
-    Previous to this call, the active form was chosen after it was rejected."""
-
+    Previous to this call, the active form was chosen after it was rejected.
+    """
     requested_slot = tracker.get("slots", {}).get(REQUESTED_SLOT)
 
     validation_questions = questionary.confirm(
@@ -1130,8 +1137,8 @@ async def _validate_action(
 ) -> bool:
     """Query the user to validate if an action prediction is correct.
 
-    Returns `True` if the prediction is correct, `False` otherwise."""
-
+    Returns `True` if the prediction is correct, `False` otherwise.
+    """
     if action_name == ACTION_UNLIKELY_INTENT_NAME:
         question = questionary.confirm(
             f"The bot wants to run '{action_name}' "
@@ -1200,8 +1207,8 @@ def _validate_user_regex(latest_message: Dict[Text, Any], intents: List[Text]) -
     """Validate if a users message input is correct.
 
     This assumes the user entered an intent directly, e.g. using
-    `/greet`. Return `True` if the intent is a known one."""
-
+    `/greet`. Return `True` if the intent is a known one.
+    """
     parse_data = latest_message.get("parse_data", {})
     intent = parse_data.get("intent", {}).get(INTENT_NAME_KEY)
 
@@ -1216,8 +1223,8 @@ async def _validate_user_text(
 ) -> bool:
     """Validate a user message input as free text.
 
-    This assumes the user message is a text message (so NOT `/greet`)."""
-
+    This assumes the user message is a text message (so NOT `/greet`).
+    """
     parse_data = latest_message.get("parse_data", {})
     text = _as_md_message(parse_data)
     intent = parse_data.get("intent", {}).get(INTENT_NAME_KEY)
@@ -1248,8 +1255,8 @@ async def _validate_nlu(
     """Validate if a user message, either text or intent is correct.
 
     If the prediction of the latest user message is incorrect,
-    the tracker will be corrected with the correct intent / entities."""
-
+    the tracker will be corrected with the correct intent / entities.
+    """
     tracker = await retrieve_tracker(
         endpoint, conversation_id, EventVerbosity.AFTER_RESTART
     )
@@ -1285,7 +1292,8 @@ async def _correct_entities(
 ) -> List[Dict[Text, Any]]:
     """Validate the entities of a user message.
 
-    Returns the corrected entities"""
+    Returns the corrected entities.
+    """
     from rasa.shared.nlu.training_data import entities_parser
 
     parse_original = latest_message.get("parse_data", {})
@@ -1330,7 +1338,6 @@ def _is_same_entity_annotation(entity: Dict[Text, Any], other: Dict[Text, Any])
 
 async def _enter_user_message(conversation_id: Text, endpoint: EndpointConfig) -> None:
     """Request a new message from the user."""
-
     question = questionary.text("Your input ->")
 
     message = await _ask_questions(question, conversation_id, endpoint, lambda a: not a)
@@ -1345,7 +1352,6 @@ async def is_listening_for_message(
     conversation_id: Text, endpoint: EndpointConfig
 ) -> bool:
     """Check if the conversation is in need for a user message."""
-
     tracker = await retrieve_tracker(endpoint, conversation_id, EventVerbosity.APPLIED)
 
     for i, e in enumerate(reversed(tracker.get("events", []))):
@@ -1358,7 +1364,6 @@ async def is_listening_for_message(
 
 async def _undo_latest(conversation_id: Text, endpoint: EndpointConfig) -> None:
     """Undo either the latest bot action or user message, whatever is last."""
-
     tracker = await retrieve_tracker(endpoint, conversation_id, EventVerbosity.ALL)
 
     # Get latest `UserUtterance` or `ActionExecuted` event.
@@ -1386,7 +1391,6 @@ async def _fetch_events(
     conversation_ids: List[Union[Text, List[Event]]], endpoint: EndpointConfig
 ) -> List[List[Event]]:
     """Retrieve all event trackers from the endpoint for all conversation ids."""
-
     event_sequences = []
     for conversation_id in conversation_ids:
         if isinstance(conversation_id, str):
@@ -1412,8 +1416,8 @@ async def _plot_trackers(
     This assumes that the last conversation id is the conversation we are currently
     working on. If there are events that are not part of this active tracker
     yet, they can be passed as part of `unconfirmed`. They will be appended
-    to the currently active conversation."""
-
+    to the currently active conversation.
+    """
     if not output_file or not conversation_ids:
         # if there is no output file provided, we are going to skip plotting
         # same happens if there are no conversation ids
@@ -1436,7 +1440,6 @@ async def _plot_trackers(
 
 def _print_help(skip_visualization: bool) -> None:
     """Print some initial help message for the user."""
-
     if not skip_visualization:
         visualization_url = DEFAULT_SERVER_FORMAT.format(
             "http", DEFAULT_SERVER_PORT + 1
@@ -1462,7 +1465,6 @@ async def record_messages(
     skip_visualization: bool = False,
 ) -> None:
     """Read messages from the command line and print bot responses."""
-
     try:
         try:
             domain = await retrieve_domain(endpoint)
@@ -1473,7 +1475,9 @@ async def record_messages(
             )
             return
 
-        intents = [next(iter(i)) for i in (domain.get("intents") or [])]
+        domain_intents = domain.get("intents", []) if domain is not None else []
+
+        intents = [next(iter(i)) for i in domain_intents]
 
         num_messages = 0
 
@@ -1585,7 +1589,6 @@ def _serve_application(
     port: int,
 ) -> Sanic:
     """Start a core server and attach the interactive learning IO."""
-
     endpoint = EndpointConfig(url=DEFAULT_SERVER_FORMAT.format("http", port))
 
     async def run_interactive_io(running_app: Sanic) -> None:
@@ -1613,8 +1616,7 @@ def _serve_application(
 
 def start_visualization(image_path: Text, port: int) -> None:
     """Add routes to serve the conversation visualization files."""
-
-    app = Sanic(__name__)
+    app = Sanic("rasa_interactive")
 
     # noinspection PyUnusedLocal
     @app.exception(NotFound)
