@@ -331,7 +331,9 @@ class ResponseSelector(DIETClassifier):
         return LABEL_SUB_KEY
 
     @staticmethod
-    def model_class(use_text_as_label: bool) -> Type[RasaModel]:
+    def model_class(  # type: ignore[override]
+        use_text_as_label: bool,
+    ) -> Type[RasaModel]:
         """Returns model class."""
         if use_text_as_label:
             return DIET2DIET
@@ -357,7 +359,7 @@ class ResponseSelector(DIETClassifier):
             self.component_config[HIDDEN_LAYERS_SIZES]
             == default_config[HIDDEN_LAYERS_SIZES]
         )
-        config_for_disabling_hidden_layers = {
+        config_for_disabling_hidden_layers: Dict[Text, List[Any]] = {
             k: [] for k, _ in default_config[HIDDEN_LAYERS_SIZES].items()
         }
         # warn if the hidden layers aren't disabled
