@@ -1373,6 +1373,7 @@ async def run_evaluation(
     errors: bool = False,
     disable_plotting: bool = False,
     report_as_dict: Optional[bool] = None,
+    domain_path: Optional[Text] = None,
 ) -> Dict:  # pragma: no cover
     """Evaluate intent classification, response selection and entity extraction.
 
@@ -1387,6 +1388,7 @@ async def run_evaluation(
             If `False` the report is returned in a human-readable text format. If `None`
             `report_as_dict` is considered as `True` in case an `output_directory` is
             given.
+        domain_path: Path to the domain file(s).
 
     Returns: dictionary containing evaluation results
     """
@@ -1394,7 +1396,8 @@ async def run_evaluation(
     from rasa.shared.constants import DEFAULT_DOMAIN_PATH
 
     test_data_importer = TrainingDataImporter.load_from_dict(
-        training_data_paths=[data_path], domain_path=DEFAULT_DOMAIN_PATH
+        training_data_paths=[data_path],
+        domain_path=domain_path if domain_path else DEFAULT_DOMAIN_PATH,
     )
     test_data = test_data_importer.get_nlu_data()
 
@@ -1730,7 +1733,7 @@ async def compute_metrics(
         response_selection_results
     )
 
-    intent_metrics = {}
+    intent_metrics: IntentMetrics = {}
     if intent_results:
         intent_metrics = _compute_metrics(
             intent_results, "intent_target", "intent_prediction"
@@ -1740,7 +1743,7 @@ async def compute_metrics(
     if entity_results:
         entity_metrics = _compute_entity_metrics(entity_results)
 
-    response_selection_metrics = {}
+    response_selection_metrics: ResponseSelectionMetrics = {}
     if response_selection_results:
         response_selection_metrics = _compute_metrics(
             response_selection_results,
@@ -1762,7 +1765,7 @@ async def compare_nlu(
     configs: List[Text],
     data: TrainingData,
     exclusion_percentages: List[int],
-    f_score_results: Dict[Text, Any],
+    f_score_results: Dict[Text, List[List[float]]],
     model_names: List[Text],
     output: Text,
     runs: int,
