@@ -6,13 +6,18 @@ import rasa.shared.constants
 import rasa.shared.utils.common
 import rasa.shared.core.constants
 import rasa.shared.utils.io
-from rasa.shared.core.domain import Domain
+from rasa.shared.core.domain import (
+    Domain,
+    KEY_E2E_ACTIONS,
+    KEY_INTENTS,
+    KEY_RESPONSES,
+    KEY_ACTIONS,
+)
 from rasa.shared.core.events import ActionExecuted, UserUttered
 from rasa.shared.core.training_data.structures import StoryGraph
 from rasa.shared.nlu.training_data.message import Message
 from rasa.shared.nlu.training_data.training_data import TrainingData
 from rasa.shared.nlu.constants import ENTITIES, ACTION_NAME
-from rasa.shared.importers.autoconfig import TrainingType
 from rasa.shared.core.domain import IS_RETRIEVAL_INTENT_KEY
 
 logger = logging.getLogger(__name__)
@@ -56,6 +61,10 @@ class TrainingDataImporter:
         """
         raise NotImplementedError()
 
+    def get_config_file_for_auto_config(self) -> Optional[Text]:
+        """Returns config file path for auto-config only if there is a single one."""
+        raise NotImplementedError()
+
     def get_nlu_data(self, language: Optional[Text] = "en") -> TrainingData:
         """Retrieves the NLU training data that should be used for training.
 
@@ -72,13 +81,11 @@ class TrainingDataImporter:
         config_path: Text,
         domain_path: Optional[Text] = None,
         training_data_paths: Optional[List[Text]] = None,
-        training_type: Optional[TrainingType] = TrainingType.BOTH,
     ) -> "TrainingDataImporter":
         """Loads a `TrainingDataImporter` instance from a configuration file."""
-
         config = rasa.shared.utils.io.read_config_file(config_path)
         return TrainingDataImporter.load_from_dict(
-            config, config_path, domain_path, training_data_paths, training_type
+            config, config_path, domain_path, training_data_paths
         )
 
     @staticmethod
@@ -91,9 +98,8 @@ class TrainingDataImporter:
 
         Instance loaded from configuration file will only read Core training data.
         """
-
         importer = TrainingDataImporter.load_from_config(
-            config_path, domain_path, training_data_paths, TrainingType.CORE
+            config_path, domain_path, training_data_paths
         )
         return importer
 
@@ -107,9 +113,8 @@ class TrainingDataImporter:
 
         Instance loaded from configuration file will only read NLU training data.
         """
-
         importer = TrainingDataImporter.load_from_config(
-            config_path, domain_path, training_data_paths, TrainingType.NLU
+            config_path, domain_path, training_data_paths
         )
 
         if isinstance(importer, E2EImporter):
@@ -125,26 +130,22 @@ class TrainingDataImporter:
         config_path: Optional[Text] = None,
         domain_path: Optional[Text] = None,
         training_data_paths: Optional[List[Text]] = None,
-        training_type: Optional[TrainingType] = TrainingType.BOTH,
     ) -> "TrainingDataImporter":
         """Loads a `TrainingDataImporter` instance from a dictionary."""
-
         from rasa.shared.importers.rasa import RasaFileImporter
 
         config = config or {}
         importers = config.get("importers", [])
         importers = [
             TrainingDataImporter._importer_from_dict(
-                importer, config_path, domain_path, training_data_paths, training_type
+                importer, config_path, domain_path, training_data_paths
             )
             for importer in importers
         ]
         importers = [importer for importer in importers if importer]
         if not importers:
             importers = [
-                RasaFileImporter(
-                    config_path, domain_path, training_data_paths, training_type
-                )
+                RasaFileImporter(config_path, domain_path, training_data_paths)
             ]
 
         return E2EImporter(ResponsesSyncImporter(CombinedDataImporter(importers)))
@@ -155,7 +156,6 @@ class TrainingDataImporter:
         config_path: Text,
         domain_path: Optional[Text] = None,
         training_data_paths: Optional[List[Text]] = None,
-        training_type: Optional[TrainingType] = TrainingType.BOTH,
     ) -> Optional["TrainingDataImporter"]:
         from rasa.shared.importers.multi_project import MultiProjectImporter
         from rasa.shared.importers.rasa import RasaFileImporter
@@ -174,8 +174,6 @@ class TrainingDataImporter:
                 logging.warning(f"Importer '{module_path}' not found.")
                 return None
 
-        importer_config = dict(training_type=training_type, **importer_config)
-
         constructor_arguments = rasa.shared.utils.common.minimal_kwargs(
             importer_config, importer_class
         )
@@ -220,6 +218,11 @@ class NluDataImporter(TrainingDataImporter):
         """Retrieves NLU training data (see parent class for full docstring)."""
         return self._importer.get_nlu_data(language)
 
+    @rasa.shared.utils.common.cached_method
+    def get_config_file_for_auto_config(self) -> Optional[Text]:
+        """Returns config file path for auto-config only if there is a single one."""
+        return self._importer.get_config_file_for_auto_config()
+
 
 class CombinedDataImporter(TrainingDataImporter):
     """A `TrainingDataImporter` that combines multiple importers.
@@ -244,7 +247,9 @@ class CombinedDataImporter(TrainingDataImporter):
         domains = [importer.get_domain() for importer in self._importers]
 
         return reduce(
-            lambda merged, other: merged.merge(other), domains, Domain.empty()
+            lambda merged, other: merged.merge(other),
+            domains,
+            Domain.empty(),
         )
 
     @rasa.shared.utils.common.cached_method
@@ -276,6 +281,17 @@ class CombinedDataImporter(TrainingDataImporter):
             lambda merged, other: merged.merge(other), nlu_data, TrainingData()
         )
 
+    @rasa.shared.utils.common.cached_method
+    def get_config_file_for_auto_config(self) -> Optional[Text]:
+        """Returns config file path for auto-config only if there is a single one."""
+        if len(self._importers) != 1:
+            rasa.shared.utils.io.raise_warning(
+                "Auto-config for multiple importers is not supported; "
+                "using config as is."
+            )
+            return None
+        return self._importers[0].get_config_file_for_auto_config()
+
 
 class ResponsesSyncImporter(TrainingDataImporter):
     """Importer that syncs `responses` between Domain and NLU training data.
@@ -293,6 +309,11 @@ class ResponsesSyncImporter(TrainingDataImporter):
         """Retrieves model config (see parent class for full docstring)."""
         return self._importer.get_config()
 
+    @rasa.shared.utils.common.cached_method
+    def get_config_file_for_auto_config(self) -> Optional[Text]:
+        """Returns config file path for auto-config only if there is a single one."""
+        return self._importer.get_config_file_for_auto_config()
+
     @rasa.shared.utils.common.cached_method
     def get_domain(self) -> Domain:
         """Merge existing domain with properties of retrieval intents in NLU data."""
@@ -309,7 +330,9 @@ class ResponsesSyncImporter(TrainingDataImporter):
             existing_domain,
         )
 
-        existing_domain = existing_domain.merge(domain_with_retrieval_intents)
+        existing_domain = existing_domain.merge(
+            domain_with_retrieval_intents, override=True
+        )
         existing_domain.check_missing_responses()
 
         return existing_domain
@@ -361,13 +384,16 @@ class ResponsesSyncImporter(TrainingDataImporter):
             intent_properties[IS_RETRIEVAL_INTENT_KEY] = True
             retrieval_intent_properties.append({intent: intent_properties})
 
-        return Domain(
-            retrieval_intent_properties,
-            [],
-            [],
-            responses,
-            ResponsesSyncImporter._construct_retrieval_action_names(retrieval_intents),
-            {},
+        action_names = ResponsesSyncImporter._construct_retrieval_action_names(
+            retrieval_intents
+        )
+
+        return Domain.from_dict(
+            {
+                KEY_INTENTS: retrieval_intent_properties,
+                KEY_RESPONSES: responses,
+                KEY_ACTIONS: action_names,
+            }
         )
 
     def get_stories(self, exclusion_percentage: Optional[int] = None) -> StoryGraph:
@@ -422,6 +448,7 @@ class E2EImporter(TrainingDataImporter):
         """Retrieves model domain (see parent class for full docstring)."""
         original = self.importer.get_domain()
         e2e_domain = self._get_domain_with_e2e_actions()
+
         return original.merge(e2e_domain)
 
     def _get_domain_with_e2e_actions(self) -> Domain:
@@ -440,15 +467,7 @@ class E2EImporter(TrainingDataImporter):
 
         additional_e2e_action_names = list(additional_e2e_action_names)
 
-        return Domain(
-            [],
-            [],
-            [],
-            {},
-            action_names=[],
-            forms={},
-            action_texts=additional_e2e_action_names,
-        )
+        return Domain.from_dict({KEY_E2E_ACTIONS: additional_e2e_action_names})
 
     def get_stories(self, exclusion_percentage: Optional[int] = None) -> StoryGraph:
         """Retrieves the stories that should be used for training.
@@ -465,6 +484,11 @@ class E2EImporter(TrainingDataImporter):
         """Retrieves model config (see parent class for full docstring)."""
         return self.importer.get_config()
 
+    @rasa.shared.utils.common.cached_method
+    def get_config_file_for_auto_config(self) -> Optional[Text]:
+        """Returns config file path for auto-config only if there is a single one."""
+        return self.importer.get_config_file_for_auto_config()
+
     @rasa.shared.utils.common.cached_method
     def get_nlu_data(self, language: Optional[Text] = "en") -> TrainingData:
         """Retrieves NLU training data (see parent class for full docstring)."""
