@@ -3,7 +3,7 @@ import copy
 import numpy as np
 import scipy.sparse
 from collections import defaultdict, OrderedDict
-from typing import List, Optional, Text, Dict, Tuple, Union, Any
+from typing import List, Optional, Text, Dict, Tuple, Union, Any, DefaultDict
 
 from rasa.nlu.constants import TOKENS_NAMES
 from rasa.utils.tensorflow.model_data import Data, FeatureArray
@@ -50,9 +50,11 @@ def featurize_training_examples(
         A dictionary of attribute to feature sizes.
     """
     output = []
+    if not entity_tag_specs:
+        entity_tag_specs = []
 
     for example in training_examples:
-        attribute_to_features = {}
+        attribute_to_features: Dict[Text, List["Features"]] = {}
         for attribute in attributes:
             if attribute == ENTITIES:
                 attribute_to_features[attribute] = []
@@ -141,7 +143,7 @@ def get_tag_ids(
 def _surface_attributes(
     features: List[List[Dict[Text, List["Features"]]]],
     featurizers: Optional[List[Text]] = None,
-) -> Dict[Text, List[List[List["Features"]]]]:
+) -> DefaultDict[Text, List[List[Optional[List["Features"]]]]]:
     """Restructure the input.
 
     "features" can, for example, be a dictionary of attributes (INTENT,
@@ -171,20 +173,21 @@ def _surface_attributes(
     )
 
     output = defaultdict(list)
-
     for list_of_attribute_to_features in features:
         intermediate_features = defaultdict(list)
         for attribute_to_features in list_of_attribute_to_features:
             for attribute in attributes:
-                features = attribute_to_features.get(attribute)
+                attribute_features = attribute_to_features.get(attribute)
                 if featurizers:
-                    features = _filter_features(features, featurizers)
+                    attribute_features = _filter_features(
+                        attribute_features, featurizers
+                    )
 
                 # if attribute is not present in the example, populate it with None
-                intermediate_features[attribute].append(features)
+                intermediate_features[attribute].append(attribute_features)
 
-        for key, value in intermediate_features.items():
-            output[key].append(value)
+        for key, collection_of_feature_collections in intermediate_features.items():
+            output[key].append(collection_of_feature_collections)
 
     return output
 
@@ -457,25 +460,25 @@ def _extract_features(
                 attribute_mask[i] = 0
                 list_of_features = fake_features
 
-            for features in list_of_features:
+            for feature in list_of_features:
                 # in case of ENTITIES, if the attribute type matches either 'entity',
                 # 'role', or 'group' the features correspond to the tag ids of that
                 # entity type in order to distinguish later on between the different
                 # tag ids, we use the entity type as key
-                if attribute == ENTITIES and features.attribute in [
+                if attribute == ENTITIES and feature.attribute in [
                     ENTITY_ATTRIBUTE_TYPE,
                     ENTITY_ATTRIBUTE_GROUP,
                     ENTITY_ATTRIBUTE_ROLE,
                 ]:
-                    key = features.attribute
+                    key = feature.attribute
                 else:
-                    key = features.type
+                    key = feature.type
 
                 # all features should have the same types
-                if features.is_sparse():
-                    dialogue_sparse_features[key].append(features.features)
+                if feature.is_sparse():
+                    dialogue_sparse_features[key].append(feature.features)
                 else:
-                    dialogue_dense_features[key].append(features.features)
+                    dialogue_dense_features[key].append(feature.features)
 
         for key, value in dialogue_sparse_features.items():
             sparse_features[key].append(value)
